@@ -10,8 +10,9 @@ import os
 import tempfile
 
 import docutils.nodes
+import docutils.utils
 from sphinx.builders import Builder
-from sphinx.util import logging
+from sphinx.util import logging, osutil
 from sphinx.util.console import red
 from sphinx.util.matching import Matcher
 from sphinx.util.osutil import ensuredir
@@ -77,7 +78,7 @@ class SpellingBuilder(Builder):
             os.mkdir(self.outdir)
 
         word_list = self.get_wordlist_filename()
-        logger.info(f'Looking for custom word list in {word_list}')
+        logger.info('Looking for custom word list in %s', word_list)
 
         self.checker = checker.SpellingChecker(
             lang=self.config.spelling_lang,
@@ -92,11 +93,11 @@ class SpellingBuilder(Builder):
         # Filters may be expressed in the configuration file using
         # names, so look through them and import the referenced class
         # and use that in the checker.
-        for filter in filters:
-            if not isinstance(filter, str):
-                yield filter
+        for filter_ in filters:
+            if not isinstance(filter_, str):
+                yield filter_
                 continue
-            module_name, _, class_name = filter.rpartition('.')
+            module_name, _, class_name = filter_.rpartition('.')
             mod = importlib.import_module(module_name)
             yield getattr(mod, class_name)
 
@@ -106,8 +107,7 @@ class SpellingBuilder(Builder):
             word_list = 'spelling_wordlist.txt'
 
         if not isinstance(word_list, list):
-            filename = os.path.join(self.srcdir, word_list)
-            return filename
+            return os.path.join(self.srcdir, word_list)
 
         # In case the user has multiple word lists, we combine them
         # into one large list that we pass on to the checker.
@@ -127,14 +127,14 @@ class SpellingBuilder(Builder):
             for word_file in word_list:
                 # Paths are relative
                 long_word_file = os.path.join(self.srcdir, word_file)
-                logger.info('Adding contents of {} to custom word list'.format(
-                    long_word_file))
+                logger.info('Adding contents of %s to custom word list',
+                            long_word_file)
                 with open(long_word_file, encoding='UTF-8') as infile:
                     infile_contents = infile.readlines()
                 outfile.writelines(infile_contents)
 
                 # Check for newline, and add one if not present
-                if infile and not infile_contents[-1].endswith('\n'):
+                if infile_contents and not infile_contents[-1].endswith('\n'):
                     outfile.write('\n')
 
         return combined_word_list
@@ -166,7 +166,7 @@ class SpellingBuilder(Builder):
         lines = list(self._find_misspellings(docname, doctree))
         self.misspelling_count += len(lines)
         if lines:
-            output_filename = os.path.join(self.outdir, docname + '.spelling')
+            output_filename = os.path.join(self.outdir, f'{docname}.spelling')
             logger.info('Writing %s', output_filename)
             ensuredir(os.path.dirname(output_filename))
             with open(output_filename, 'w', encoding='UTF-8') as output:
@@ -194,35 +194,37 @@ class SpellingBuilder(Builder):
                     node.parent and
                     node.parent.tagname in self.TEXT_NODES):
 
-                # Figure out the line number for this node by climbing the
-                # tree until we find a node that has a line number.
-                lineno = None
-                parent = node
-                seen = set()
-                while lineno is None:
-                    # logger.info('looking for line number on %r' % node)
-                    seen.add(parent)
-                    parent = node.parent
-                    if parent is None or parent in seen:
-                        break
-                    lineno = parent.line
+                # Get the location of the text being checked so we can
+                # report it in the output file. Nodes from text that
+                # comes in via an 'include' directive does not include
+                # the full path, so convert all to relative path
+                # for consistency.
+                source, lineno = docutils.utils.get_source_line(node)
+                source = osutil.relpath(source)
 
                 # Check the text of the node.
                 misspellings = self.checker.check(node.astext())
-                for word, suggestions, context_line in misspellings:
-                    msg_parts = ['Spell check', red(word)]
+                for (
+                    word,
+                    suggestions,
+                    context_line,
+                    line_offset
+                ) in misspellings:
+                    msg_parts = [
+                        f'{source}:{lineno+line_offset}: ',
+                        'Spell check',
+                        red(word),
+                    ]
                     if self.format_suggestions(suggestions) != '':
                         msg_parts.append(self.format_suggestions(suggestions))
                     msg_parts.append(context_line)
                     msg = ': '.join(msg_parts) + '.'
-                    loc = (docname, lineno) if lineno else docname
                     if self.config.spelling_warning:
-                        logger.warning(msg, location=loc)
+                        logger.warning(msg)
                     elif self.config.spelling_verbose:
-                        logger.info(msg, location=loc)
+                        logger.info(msg)
                     yield "%s:%s: (%s) %s %s\n" % (
-                        self.env.doc2path(docname, None),
-                        lineno, word,
+                        source, lineno + line_offset, word,
                         self.format_suggestions(suggestions),
                         context_line,
                     )
@@ -232,6 +234,5 @@ class SpellingBuilder(Builder):
 
     def finish(self):
         if self.misspelling_count:
-            logger.warning('Found %d misspelled words' %
+            logger.warning('Found %d misspelled words',
                            self.misspelling_count)
-        return
